@@ -17,7 +17,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.39_01';
+our $VERSION = '0.40_01';
 require XSLoader;
 XSLoader::load (__PACKAGE__, $VERSION);
 
@@ -84,4 +84,22 @@ sub json_file_to_perl
     return parse_json ($json);
 }
 
+sub run
+{
+    my ($parser, $json) = @_;
+    if ($parser->get_warn_only ()) {
+	my $out;
+	eval {
+	    $out = $parser->run_internal ($json);
+	};
+	if ($@) {
+	    warn "$@";
+	}
+	return $out;
+    }
+    else {
+	return $parser->run_internal ($json);
+    }
+}
+
 1;
